# Native imports
from imageextras.src.utils import *



# Compiled imports
import os
import platform
import sys

system = platform.system()

if sys.version_info >= (3, 10):
    py_ver = "py310"
elif sys.version_info >= (3, 9):
    py_ver = "py39"
else:
    raise RuntimeError("Unsupported Python version")

if system == "Windows":
    os_choice = "win"
elif system == "Linux":
    os_choice = "linux"
else:
    raise OSError(f"Unsupported platform: {system}")

module_names = ["dithering"] # modules to add

for module_name in module_names:
    module_dir = os.path.join("imageextras", "compiled", py_ver, os_choice)
    sys.path.append(module_dir)
    __import__(module_name)



import numpy as np

class basic ():
    
    def average (img):
        """Returns Average of RGB image

        Args:
            img (numpy.ndarray): RGB image (M,N,3)

        Returns:
            average (numpy.ndarray): Gray-scale image (M,N)
        """
        return (img[:,:,0] + img[:,:,1] + img[:,:,2])*(1/3)
    
    def luma (img):
        """Returns LUMA of RGB image

        Args:
            img (numpy.ndarray): RGB image (M,N,3)

        Returns:
            luma (numpy.ndarray): Gray-scale image (M,N)
        """
        return 0.299*img[:,:,0] + 0.587*img[:,:,1] + 0.114*img[:,:,2]
    
    
class lut ():
    
    def linear (gl, m, n):
        """Returns linearization of gray-scale image

        Args:
            gl (numpy.ndarray): Gray-scale image (M,N)
            m (scalar): Slope of linearization
            n (scalar): Bias of linearization

        Returns:
            numpy.ndarray: Linearization of gl
        """
        return m*gl + n
    
    def logistic (gl, k, gl0):
        """_summary_

        Args:
            gl (numpy.ndarray): Gray-scale image (M,N)
            k (scalar): Exponential coefficient
            gl0 (scalar): Cutoff gray level

        Returns:
            numpy.ndarray: Logistic LUT of gl
        """
        return np.max(gl) / (1 + np.exp(-k*(gl - gl0)))


from setuptools import setup, Extension, find_packages
import sys, os

version = '0.1.5.2'

setup(name='ImageExtras',
      version=version,
      description="Image Processing extra functions",
      long_description="""\
            Utilities and compiled algorithms to make Image Processing easier""",
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='image img dither luma',
      author='Adrià Brú i Cortés',
      author_email='adriabrucortes@gmail.com',
      url='https://gitlab.com/adriabrucortes/imageextras',
      license='GPL3',
      packages = find_packages(), # get all directories with __init__.py in it
      include_package_data=True,
      zip_safe=True,
      install_requires=[
          'numpy'
      ],
      requires_python = ">=3.9, <3.11"
      )
